[jboss-cvs] JBossAS SVN: r84163 - branches/Branch_5_0/varia/src/main/org/jboss/tools.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Feb 13 06:08:35 EST 2009


Author: dimitris at jboss.org
Date: 2009-02-13 06:08:34 -0500 (Fri, 13 Feb 2009)
New Revision: 84163

Modified:
   branches/Branch_5_0/varia/src/main/org/jboss/tools/SerialVersionUID.java
Log:
JBAS-650, take into account jars in JBOSS_HOME/common/** when comparing SerialVersionUIDs with previous versions.

Modified: branches/Branch_5_0/varia/src/main/org/jboss/tools/SerialVersionUID.java
===================================================================
--- branches/Branch_5_0/varia/src/main/org/jboss/tools/SerialVersionUID.java	2009-02-13 10:36:32 UTC (rev 84162)
+++ branches/Branch_5_0/varia/src/main/org/jboss/tools/SerialVersionUID.java	2009-02-13 11:08:34 UTC (rev 84163)
@@ -42,6 +42,7 @@
  * jboss home directory.
  * 
  * @author Scott.Stark at jboss.org
+ * @author Dimitris.Andreadis at jboss.org
  * @version $Revision$
  */
 public class SerialVersionUID
@@ -134,10 +135,12 @@
    public static Map generateJBossSerialVersionUIDReport(File jbossHome)
       throws IOException
    {
       // Obtain the jars from the /lib and /server/all locations
       HashSet jarFiles = new HashSet();
       File lib = new File(jbossHome, "lib");
       buildJarSet(lib, jarFiles);
+      File common = new File(jbossHome, "common");
+      buildJarSet(common, jarFiles);
       File all = new File(jbossHome, "server/all");
       buildJarSet(all, jarFiles);
       URL[] cp = new URL[jarFiles.size()];
@@ -134,10 +135,12 @@
       throws IOException
    {
-      // Obtain the jars from the /lib and /server/all locations
+      // Obtain the jars from the /lib, common/ and /server/all locations
       HashSet jarFiles = new HashSet();
       File lib = new File(jbossHome, "lib");




More information about the jboss-cvs-commits mailing list